==> wxwidgets_3.3.2-60_x86-mingw-static.zip: installed/x86-mingw-static/share/wxwidgets/wxWidgetsTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Debug"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "C;CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/debug/lib/libwx_baseu-3.3.a" )

# Import target "wx::wxnet" for configuration "Debug"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_net-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_net-3.3.a" )

# Import target "wx::wxcore" for configuration "Debug"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_core-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_core-3.3.a" )

# Import target "wx::wxadv" for configuration "Debug"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_adv-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_adv-3.3.a" )

# Import target "wx::wxaui" for configuration "Debug"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_aui-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_aui-3.3.a" )

# Import target "wx::wxhtml" for configuration "Debug"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_html-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_html-3.3.a" )

# Import target "wx::wxpropgrid" for configuration "Debug"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_propgrid-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_propgrid-3.3.a" )

# Import target "wx::wxribbon" for configuration "Debug"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_ribbon-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_ribbon-3.3.a" )

# Import target "wx::wxrichtext" for configuration "Debug"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_richtext-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_richtext-3.3.a" )

# Import target "wx::wxwebview" for configuration "Debug"
set_property(TARGET wx::wxwebview APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxwebview PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_webview-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxwebview )
list(APPEND _cmake_import_check_files_for_wx::wxwebview "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_webview-3.3.a" )

# Import target "wx::wxscintilla" for configuration "Debug"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwxscintilla-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/debug/lib/libwxscintilla-3.3.a" )

# Import target "wx::wxlexilla" for configuration "Debug"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwxlexilla-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/debug/lib/libwxlexilla-3.3.a" )

# Import target "wx::wxstc" for configuration "Debug"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_stc-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_stc-3.3.a" )

# Import target "wx::wxxrc" for configuration "Debug"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_xrc-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_xrc-3.3.a" )

# Import target "wx::wxgl" for configuration "Debug"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_gl-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_gl-3.3.a" )

# Import target "wx::wxqa" for configuration "Debug"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_qa-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_qa-3.3.a" )

# Import target "wx::wxxml" for configuration "Debug"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_xml-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_xml-3.3.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> wxwidgets_3.3.2-71-r5_x86-mingw-static.zip: installed/x86-mingw-static/share/wxwidgets/wxWidgetsTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Debug"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "C;CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud.a"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/debug/lib/wxbase33ud.a" )

# Import target "wx::wxnet" for configuration "Debug"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_net.a"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_net.a" )

# Import target "wx::wxcore" for configuration "Debug"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_core.a"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_core.a" )

# Import target "wx::wxadv" for configuration "Debug"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_adv.a"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_adv.a" )

# Import target "wx::wxaui" for configuration "Debug"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_aui.a"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_aui.a" )

# Import target "wx::wxhtml" for configuration "Debug"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_html.a"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_html.a" )

# Import target "wx::wxpropgrid" for configuration "Debug"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_propgrid.a"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_propgrid.a" )

# Import target "wx::wxribbon" for configuration "Debug"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_ribbon.a"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_ribbon.a" )

# Import target "wx::wxrichtext" for configuration "Debug"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_richtext.a"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_richtext.a" )

# Import target "wx::wxscintilla" for configuration "Debug"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxscintillad.a"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/debug/lib/wxscintillad.a" )

# Import target "wx::wxlexilla" for configuration "Debug"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxlexillad.a"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/debug/lib/wxlexillad.a" )

# Import target "wx::wxstc" for configuration "Debug"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_stc.a"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_stc.a" )

# Import target "wx::wxxrc" for configuration "Debug"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_xrc.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_xrc.a" )

# Import target "wx::wxgl" for configuration "Debug"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_gl.a"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_gl.a" )

# Import target "wx::wxqa" for configuration "Debug"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_qa.a"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_qa.a" )

# Import target "wx::wxxml" for configuration "Debug"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_xml.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_xml.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
